# Lichess.org API reference

# Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 

This Scala Play Framework project was generated by the OpenAPI generator tool at 2021-12-01T01:36:35.216324+01:00[Europe/Vienna].

## API

### Account

|Name|Role|
|----|----|
|`api.AccountController`|Play Framework API controller|
|`api.AccountApi`|Representing trait|
|`api.AccountApiImpl`|Default implementation|

* `GET /api/account/preferences` - Get my preferences
* `GET /api/account/email` - Get my email address
* `GET /api/account/kid` - Get my kid mode status
* `POST /api/account/kid?v=[value]` - Set my kid mode status
* `GET /api/account` - Get my profile

### Analysis

|Name|Role|
|----|----|
|`api.AnalysisController`|Play Framework API controller|
|`api.AnalysisApi`|Representing trait|
|`api.AnalysisApiImpl`|Default implementation|

* `GET /api/cloud-eval?fen=[value]&multiPv=[value]&variant=[value]` - Get cloud evaluation of a position.

### ArenaTournaments

|Name|Role|
|----|----|
|`api.ArenaTournamentsController`|Play Framework API controller|
|`api.ArenaTournamentsApi`|Representing trait|
|`api.ArenaTournamentsApiImpl`|Default implementation|

* `GET /api/team/:teamId/arena?max=[value]` - Get team Arena tournaments
* `GET /api/tournament` - Get current tournaments
* `POST /api/tournament/:id/join` - Join an Arena tournament
* `POST /api/tournament` - Create a new Arena tournament
* `POST /api/tournament/team-battle/:id` - Update a team battle
* `POST /api/tournament/:id/terminate` - Terminate an Arena tournament
* `POST /api/tournament/:id` - Update an Arena tournament
* `POST /api/tournament/:id/withdraw` - Pause of leave an Arena tournament
* `GET /api/user/:username/tournament/created?status=[value]` - Get tournaments created by a user
* `GET /api/tournament/:id/games?player=[value]&moves=[value]&pgnInJson=[value]&tags=[value]&clocks=[value]&evals=[value]&opening=[value]` - Export games of an Arena tournament
* `GET /api/tournament/:id/results?nb=[value]` - Get results of an Arena tournament
* `GET /api/tournament/:id/teams` - Get team standing of a team battle
* `GET /api/tournament/:id?page=[value]` - Get info about an Arena tournament

### Board

|Name|Role|
|----|----|
|`api.BoardController`|Play Framework API controller|
|`api.BoardApi`|Representing trait|
|`api.BoardApiImpl`|Default implementation|

* `POST /api/board/seek` - Create a seek
* `GET /api/stream/event` - Stream incoming events
* `POST /api/board/game/:gameId/abort` - Abort a game
* `GET /api/board/game/:gameId/chat` - Fetch the game chat
* `POST /api/board/game/:gameId/chat` - Write in the chat
* `POST /api/board/game/:gameId/claim-victory` - Claim victory of a game
* `POST /api/board/game/:gameId/draw/:accept` - Handle draw offers
* `POST /api/board/game/:gameId/move/:move?offeringDraw=[value]` - Make a Board move
* `POST /api/board/game/:gameId/resign` - Resign a game
* `GET /api/board/game/stream/:gameId` - Stream Board game state
* `POST /api/board/game/:gameId/takeback/:accept` - Handle takeback offers

### Bot

|Name|Role|
|----|----|
|`api.BotController`|Play Framework API controller|
|`api.BotApi`|Representing trait|
|`api.BotApiImpl`|Default implementation|

* `GET /api/bot/online?nb=[value]` - Get online bots
* `GET /api/stream/event` - Stream incoming events
* `POST /api/bot/account/upgrade` - Upgrade to Bot account
* `POST /api/bot/game/:gameId/abort` - Abort a game
* `POST /api/bot/game/:gameId/chat` - Write in the chat
* `POST /api/bot/game/:gameId/move/:move?offeringDraw=[value]` - Make a Bot move
* `POST /api/bot/game/:gameId/resign` - Resign a game
* `GET /api/bot/game/stream/:gameId` - Stream Bot game state

### Broadcasts

|Name|Role|
|----|----|
|`api.BroadcastsController`|Play Framework API controller|
|`api.BroadcastsApi`|Representing trait|
|`api.BroadcastsApiImpl`|Default implementation|

* `GET /api/broadcast/:broadcastTournamentId.pgn` - Export all rounds as PGN
* `GET /api/broadcast?nb=[value]` - Get official broadcasts
* `POST /broadcast/round/:broadcastRoundId/push` - Push PGN to your broadcast round
* `POST /broadcast/:broadcastTournamentId/new` - Create a broadcast round
* `GET /broadcast/:broadcastTournamentSlug/:broadcastRoundSlug/:broadcastRoundId` - Get your broadcast round
* `GET /api/broadcast/round/:broadcastRoundId.pgn` - Export one round as PGN
* `POST /broadcast/round/:broadcastRoundId/edit` - Update your broadcast round
* `GET /api/stream/broadcast/round/:broadcastRoundId.pgn` - Stream an ongoing broadcast tournament as PGN
* `POST /broadcast/new` - Create a broadcast tournament
* `GET /broadcast/:slug/:broadcastTournamentId` - Get your broadcast tournament
* `POST /broadcast/:broadcastTournamentId/edit` - Update your broadcast tournament

### BulkPairings

|Name|Role|
|----|----|
|`api.BulkPairingsController`|Play Framework API controller|
|`api.BulkPairingsApi`|Representing trait|
|`api.BulkPairingsApiImpl`|Default implementation|

* `POST /api/bulk-pairing` - Create a bulk pairing
* `DELETE /api/bulk-pairing/:id` - Cancel a bulk pairing
* `GET /api/bulk-pairing` - View upcoming bulk pairings
* `POST /api/bulk-pairing/:id/start-clocks` - Manually start clocks

### Challenges

|Name|Role|
|----|----|
|`api.ChallengesController`|Play Framework API controller|
|`api.ChallengesApi`|Representing trait|
|`api.ChallengesApiImpl`|Default implementation|

* `POST /api/token/admin-challenge` - Admin challenge tokens
* `POST /api/challenge/:challengeId/accept` - Accept a challenge
* `POST /api/challenge/ai` - Challenge the AI
* `POST /api/challenge/:challengeId/cancel?opponentToken=[value]` - Cancel a challenge
* `POST /api/challenge/:username` - Create a challenge
* `POST /api/challenge/:challengeId/decline` - Decline a challenge
* `GET /api/challenge` - List your challenges
* `POST /api/challenge/open` - Open-ended challenge
* `POST /api/challenge/:gameId/start-clocks?token1=[value]&token2=[value]` - Start clocks of a game
* `POST /api/round/:gameId/add-time/:seconds` - Add time to the opponent clock

### Games

|Name|Role|
|----|----|
|`api.GamesController`|Play Framework API controller|
|`api.GamesApi`|Representing trait|
|`api.GamesApiImpl`|Default implementation|

* `GET /api/account/playing?nb=[value]` - Get my ongoing games
* `GET /api/games/user/:username?since=[value]&until=[value]&max=[value]&vs=[value]&rated=[value]&perfType=[value]&color=[value]&analysed=[value]&moves=[value]&pgnInJson=[value]&tags=[value]&clocks=[value]&evals=[value]&opening=[value]&ongoing=[value]&finished=[value]&players=[value]&sort=[value]` - Export games of a user
* `GET /api/user/:username/current-game?moves=[value]&pgnInJson=[value]&tags=[value]&clocks=[value]&evals=[value]&opening=[value]&literate=[value]&players=[value]` - Export ongoing game of a user
* `POST /api/import` - Import one game
* `GET /game/export/:gameId?moves=[value]&pgnInJson=[value]&tags=[value]&clocks=[value]&evals=[value]&opening=[value]&literate=[value]&players=[value]` - Export one game
* `POST /api/stream/games-by-users?withCurrentGames=[value]` - Stream games of users
* `POST /games/export/_ids?moves=[value]&pgnInJson=[value]&tags=[value]&clocks=[value]&evals=[value]&opening=[value]&players=[value]` - Export games by IDs
* `GET /api/stream/game/:id` - Stream moves of a game

### Messaging

|Name|Role|
|----|----|
|`api.MessagingController`|Play Framework API controller|
|`api.MessagingApi`|Representing trait|
|`api.MessagingApiImpl`|Default implementation|

* `POST /inbox/:username` - Send a private message

### OAuth

|Name|Role|
|----|----|
|`api.OAuthController`|Play Framework API controller|
|`api.OAuthApi`|Representing trait|
|`api.OAuthApiImpl`|Default implementation|

* `POST /api/token` - Obtain access token
* `DELETE /api/token` - Revoke access token
* `GET /oauth?responseType=[value]&clientId=[value]&redirectUri=[value]&codeChallengeMethod=[value]&codeChallenge=[value]&scope=[value]&state=[value]` - Request authorization code

### OpeningExplorer

|Name|Role|
|----|----|
|`api.OpeningExplorerController`|Play Framework API controller|
|`api.OpeningExplorerApi`|Representing trait|
|`api.OpeningExplorerApiImpl`|Default implementation|

* `GET /lichess?variant=[value]&fen=[value]&play=[value]&speeds=[value]&ratings=[value]&since=[value]&until=[value]&moves=[value]&topGames=[value]&recentGames=[value]` - Lichess games
* `GET /masters?fen=[value]&play=[value]&since=[value]&until=[value]&moves=[value]&topGames=[value]` - Masters database
* `GET /master/pgn/:gameId` - OTB master game
* `GET /player??variant=[value]&fen=[value]&play=[value]&speeds=[value]&modes=[value]&since=[value]&until=[value]&moves=[value]&recentGames=[value]` - Player games

### Puzzles

|Name|Role|
|----|----|
|`api.PuzzlesController`|Play Framework API controller|
|`api.PuzzlesApi`|Representing trait|
|`api.PuzzlesApiImpl`|Default implementation|

* `GET /api/puzzle/activity?max=[value]` - Get your puzzle activity
* `GET /api/puzzle/daily` - Get the daily puzzle
* `GET /api/puzzle/dashboard/:days` - Get your puzzle dashboard
* `GET /api/storm/dashboard/:username?days=[value]` - Get the storm dashboard of a player

### Relations

|Name|Role|
|----|----|
|`api.RelationsController`|Play Framework API controller|
|`api.RelationsApi`|Representing trait|
|`api.RelationsApiImpl`|Default implementation|

* `GET /api/rel/following` - Get users followed the logged in user
* `POST /api/rel/follow/:username` - Follow a player
* `POST /api/rel/unfollow/:username` - Unfollow a player

### Simuls

|Name|Role|
|----|----|
|`api.SimulsController`|Play Framework API controller|
|`api.SimulsApi`|Representing trait|
|`api.SimulsApiImpl`|Default implementation|

* `GET /api/simul` - Get current simuls

### Studies

|Name|Role|
|----|----|
|`api.StudiesController`|Play Framework API controller|
|`api.StudiesApi`|Representing trait|
|`api.StudiesApiImpl`|Default implementation|

* `GET /api/study/:studyId.pgn?clocks=[value]&comments=[value]&variations=[value]` - Export all chapters
* `GET /study/:studyId/:chapterId.pgn?clocks=[value]&comments=[value]&variations=[value]` - Export one study chapter
* `GET /study/by/:username/export.pgn?clocks=[value]&comments=[value]&variations=[value]` - Export all studies of a user

### SwissTournaments

|Name|Role|
|----|----|
|`api.SwissTournamentsController`|Play Framework API controller|
|`api.SwissTournamentsApi`|Representing trait|
|`api.SwissTournamentsApiImpl`|Default implementation|

* `POST /api/swiss/:id/join` - Join a Swiss tournament
* `POST /api/swiss/new/:teamId` - Create a new Swiss tournament
* `POST /api/swiss/:id/terminate` - Terminate a Swiss tournament
* `POST /api/swiss/:id/edit` - Update a Swiss tournament.
* `GET /api/team/:teamId/swiss?max=[value]` - Get team swiss tournaments
* `GET /api/swiss/:id/games?moves=[value]&pgnInJson=[value]&tags=[value]&clocks=[value]&evals=[value]&opening=[value]` - Export games of a Swiss tournament
* `GET /api/swiss/:id/results?nb=[value]` - Get results of a swiss tournament
* `GET /swiss/:id.trf` - Export TRF of a Swiss tournament

### TV

|Name|Role|
|----|----|
|`api.TVController`|Play Framework API controller|
|`api.TVApi`|Representing trait|
|`api.TVApiImpl`|Default implementation|

* `GET /api/tv/:channel?nb=[value]&moves=[value]&pgnInJson=[value]&tags=[value]&clocks=[value]&opening=[value]` - Get best ongoing games of a TV channel
* `GET /api/tv/channels` - Get current TV games
* `GET /api/tv/feed` - Stream current TV game

### Tablebase

|Name|Role|
|----|----|
|`api.TablebaseController`|Play Framework API controller|
|`api.TablebaseApi`|Representing trait|
|`api.TablebaseApiImpl`|Default implementation|

* `GET /antichess` - Tablebase lookup for Antichess
* `GET /atomic` - Tablebase lookup for Atomic chess
* `GET /standard?fen=[value]` - Tablebase lookup

### Teams

|Name|Role|
|----|----|
|`api.TeamsController`|Play Framework API controller|
|`api.TeamsApi`|Representing trait|
|`api.TeamsApiImpl`|Default implementation|

* `GET /api/team/:teamId/arena?max=[value]` - Get team Arena tournaments
* `GET /api/team/:teamId/swiss?max=[value]` - Get team swiss tournaments
* `GET /api/team/all?page=[value]` - Get popular teams
* `POST /team/:teamId/join` - Join a team
* `POST /team/:teamId/kick/:userId` - Kick a user from your team
* `POST /team/:teamId/pm-all` - Message all members
* `POST /team/:teamId/quit` - Leave a team
* `GET /api/team/:teamId/users` - Get members of a team
* `GET /api/team/of/:username` - Teams of a player
* `GET /api/team/search?text=[value]&page=[value]` - Search teams
* `GET /api/team/:teamId` - Get a single team

### Users

|Name|Role|
|----|----|
|`api.UsersController`|Play Framework API controller|
|`api.UsersApi`|Representing trait|
|`api.UsersApiImpl`|Default implementation|

* `GET /api/crosstable/:user1/:user2?matchup=[value]` - Get crosstable
* `GET /api/user/:username` - Get user public data
* `GET /api/user/:username/activity` - Get user activity
* `GET /api/user/:username/perf/:perf` - Get performance statistics of a user
* `GET /api/user/:username/rating-history` - Get rating history of a user
* `POST /api/users` - Get users by ID
* `GET /api/users/status?ids=[value]` - Get real-time users status
* `GET /player` - Get all top 10
* `GET /player/top/:nb/:perfType` - Get one leaderboard
* `GET /streamer/live` - Get live streamers
* `GET /api/team/:teamId/users` - Get members of a team

