package api

import play.api.libs.json._
import model.ArenaTournaments
import model.BigDecimal
import model.Error
import model.OasAnyTypeNotMapped
import model.Ok
import model.VariantKey

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait ArenaTournamentsApi {
  /**
    * Get team Arena tournaments
    * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param teamId ID of the team
    * @param max How many tournaments to download.
    */
  def apiTeamArena(teamId: String, max: Option[Int]): List[OasAnyTypeNotMapped]

  /**
    * Get current tournaments
    * Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 
    */
  def apiTournament(): ArenaTournaments

  /**
    * Join an Arena tournament
    * Join an Arena tournament, possibly with a password and/or a team. 
    * @param id The tournament ID.
    * @param password The tournament password, if one is required
    * @param team The team to join the tournament with, for team battle tournaments
    */
  def apiTournamentJoin(id: String, password: Option[String], team: Option[String]): Ok

  /**
    * Create a new Arena tournament
    * Create a public or private Arena tournament.  This endpoint mirrors the form on &lt;https://lichess.org/tournament/new&gt;.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the &#x60;teambBattleByTeam&#x60; argument. 
    * @param clockTime Clock initial time in minutes
    * @param clockIncrement Clock increment in seconds
    * @param minutes How long the tournament lasts, in minutes
    * @param name The tournament name. Leave empty to get a random Grandmaster name
    * @param waitMinutes How long to wait before starting the tournament, from now, in minutes
    * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting
    * @param rated Games are rated and impact players ratings
    * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
    * @param berserkable Whether the players can use berserk
    * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2.
    * @param hasChat Whether the players can discuss in a chat
    * @param description Anything you want to tell players about the tournament
    * @param password Make the tournament private, and restrict access with a password
    * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost). 
    * @param conditionsPeriodteamMemberPeriodteamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead. 
    * @param conditionsPeriodminRatingPeriodrating Minimum rating to join. Leave empty to let everyone join the tournament.
    * @param conditionsPeriodmaxRatingPeriodrating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
    * @param conditionsPeriodnbRatedGamePeriodnb Minimum number of rated games required to join.
    */
  def apiTournamentPost(clockTime: BigDecimal, clockIncrement: Int, minutes: Int, name: Option[String], waitMinutes: Option[Int], startDate: Option[Int], variant: Option[VariantKey], rated: Option[Boolean], position: Option[String], berserkable: Option[Boolean], streakable: Option[Boolean], hasChat: Option[Boolean], description: Option[String], password: Option[String], teambBattleByTeam: Option[String], conditionsPeriodteamMemberPeriodteamId: Option[String], conditionsPeriodminRatingPeriodrating: Option[Int], conditionsPeriodmaxRatingPeriodrating: Option[Int], conditionsPeriodnbRatedGamePeriodnb: Option[Int]): OasAnyTypeNotMapped

  /**
    * Update a team battle
    * Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 
    * @param id The tournament ID (8 characters)..
    * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60; 
    * @param nbLeaders Number team leaders per team.
    */
  def apiTournamentTeamBattlePost(id: String, teams: String, nbLeaders: Int): OasAnyTypeNotMapped

  /**
    * Terminate an Arena tournament
    * Terminate an Arena tournament 
    * @param id The tournament ID.
    */
  def apiTournamentTerminate(id: String): Ok

  /**
    * Update an Arena tournament
    * Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 
    * @param id The tournament ID.
    * @param clockTime Clock initial time in minutes
    * @param clockIncrement Clock increment in seconds
    * @param minutes How long the tournament lasts, in minutes
    * @param name The tournament name. Leave empty to get a random Grandmaster name
    * @param waitMinutes How long to wait before starting the tournament, from now, in minutes
    * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting
    * @param rated Games are rated and impact players ratings
    * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
    * @param berserkable Whether the players can use berserk
    * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2.
    * @param hasChat Whether the players can discuss in a chat
    * @param description Anything you want to tell players about the tournament
    * @param password Make the tournament private, and restrict access with a password
    * @param conditionsPeriodminRatingPeriodrating Minimum rating to join. Leave empty to let everyone join the tournament.
    * @param conditionsPeriodmaxRatingPeriodrating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
    * @param conditionsPeriodnbRatedGamePeriodnb Minimum number of rated games required to join.
    */
  def apiTournamentUpdate(id: String, clockTime: BigDecimal, clockIncrement: Int, minutes: Int, name: Option[String], waitMinutes: Option[Int], startDate: Option[Int], variant: Option[VariantKey], rated: Option[Boolean], position: Option[String], berserkable: Option[Boolean], streakable: Option[Boolean], hasChat: Option[Boolean], description: Option[String], password: Option[String], conditionsPeriodminRatingPeriodrating: Option[Int], conditionsPeriodmaxRatingPeriodrating: Option[Int], conditionsPeriodnbRatedGamePeriodnb: Option[Int]): OasAnyTypeNotMapped

  /**
    * Pause of leave an Arena tournament
    * Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It&#39;s possible to join again later. Points and streaks are preserved. 
    * @param id The tournament ID.
    */
  def apiTournamentWithdraw(id: String): Ok

  /**
    * Get tournaments created by a user
    * Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param username The user whose created tournaments to fetch
    * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60; 
    */
  def apiUserNameTournamentCreated(username: String, status: Option[Int]): OasAnyTypeNotMapped

  /**
    * Export games of an Arena tournament
    * Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 
    * @param id The tournament ID.
    * @param player Only games of a particular player. Leave empty to fetch games of all players.
    * @param moves Include the PGN moves.
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
    * @param tags Include the PGN tags.
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
    */
  def gamesByTournament(id: String, player: Option[String], moves: Option[Boolean], pgnInJson: Option[Boolean], tags: Option[Boolean], clocks: Option[Boolean], evals: Option[Boolean], opening: Option[Boolean]): OasAnyTypeNotMapped

  /**
    * Get results of an Arena tournament
    * Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
    * @param id The tournament ID.
    * @param nb Max number of players to fetch
    */
  def resultsByTournament(id: String, nb: Option[Int]): OasAnyTypeNotMapped

  /**
    * Get team standing of a team battle
    * Teams of a team battle tournament, with top players, sorted by rank (best first). 
    * @param id The tournament ID.
    */
  def teamsByTournament(id: String): OasAnyTypeNotMapped

  /**
    * Get info about an Arena tournament
    * Get detailed info about recently finished, current, or upcoming tournament&#39;s duels, player standings, and other info. 
    * @param id The tournament ID.
    * @param page Specify which page of player standings to view.
    */
  def tournament(id: String, page: Option[BigDecimal]): OasAnyTypeNotMapped
}
