package api

import play.api.libs.json._
import model.ApiStreamEvent
import model.BigDecimal
import model.Error
import model.GameStreamEvent
import model.NotFound
import model.OasAnyTypeNotMapped
import model.Ok
import model.VariantKey

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait BoardApi {
  /**
    * Create a seek
    *    Create a public seek, to start a game with a random player.    ### Real-time seek    Specify the &#x60;time&#x60; and &#x60;increment&#x60; clock values.  The response is streamed but doesn&#39;t contain any information.    **Keep the connection open to keep the seek active**.    If the client closes the connection, the seek is canceled. This way, if the client terminates, the user won&#39;t be paired in a game they wouldn&#39;t play.   When the seek is accepted, or expires, the server closes the connection.    **Make sure to also have an [Event stream](#operation/apiStreamEvent) open**, to be notified when a game starts.   We recommend opening the [Event stream](#operation/apiStreamEvent) first, then the seek stream. This way,   you won&#39;t miss the game event if the seek is accepted immediately.    ### Correspondence seek    Specify the &#x60;days&#x60; per turn value.  The response is not streamed, it immediately completes with the seek ID. The seek remains active on the server until it is joined by someone.
    * @param rated Whether the game is rated and impacts players ratings.
    * @param time Clock initial time in minutes. Required for real-time seeks.
    * @param increment Clock increment in seconds. Required for real-time seeks.
    * @param days Days per turn. Required for correspondence seeks.
    * @param color The color to play. Better left empty to automatically get 50% white.
    * @param ratingRange The rating range of potential opponents. Better left empty. Example: 1500-1800 
    */
  def apiBoardSeek(rated: Option[Boolean], time: Option[BigDecimal], increment: Option[Int], days: Option[Int], variant: Option[VariantKey], color: Option[String], ratingRange: Option[String]): Unit

  /**
    * Stream incoming events
    *    Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameStart&#x60; Start of a game   - &#x60;gameFinish&#x60; Completion of a game   - &#x60;challenge&#x60; A player sends you a challenge   - &#x60;challengeCanceled&#x60; A player cancels their challenge to you   - &#x60;challengeDeclined&#x60; The opponent declines your challenge     When the stream opens, all current challenges and games are sent.
    */
  def apiStreamEvent(): ApiStreamEvent

  /**
    * Abort a game
    * Abort a game being played with the Board API. 
    */
  def boardGameAbort(gameId: String): Ok

  /**
    * Fetch the game chat
    * Get the messages posted in the game chat 
    */
  def boardGameChatGet(gameId: String): OasAnyTypeNotMapped

  /**
    * Write in the chat
    * Post a message to the player or spectator chat, in a game being played with the Board API. 
    */
  def boardGameChatPost(gameId: String, room: String, text: String): Ok

  /**
    * Claim victory of a game
    * Claim victory when the opponent has left the game for a while. 
    */
  def boardGameClaimVictory(gameId: String): Ok

  /**
    * Handle draw offers
    * Create/accept/decline draw offers. - &#x60;yes&#x60;: Offer a draw, or accept the opponent&#39;s draw offer. - &#x60;no&#x60;: Decline a draw offer from the opponent. 
    */
  def boardGameDraw(gameId: String, accept: Boolean): Ok

  /**
    * Make a Board move
    * Make a move in a game being played with the Board API.  The move can also contain a draw offer/agreement. 
    * @param move The move to play, in UCI format
    * @param offeringDraw Whether to offer (or agree to) a draw
    */
  def boardGameMove(gameId: String, move: String, offeringDraw: Option[Boolean]): Ok

  /**
    * Resign a game
    * Resign a game being played with the Board API. 
    */
  def boardGameResign(gameId: String): Ok

  /**
    * Stream Board game state
    *  Stream the state of a game being played with the Board API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameFull&#x60; Full game data. All values are immutable, except for the &#x60;state&#x60; field.   - &#x60;gameState&#x60; Current state of the game. Immutable values not included. Sent when a move is played, a draw is offered, or when the game ends.   - &#x60;chatLine&#x60; Chat message sent by a user in the &#x60;room&#x60; \&quot;player\&quot; or \&quot;spectator\&quot;.    The first line is always of type &#x60;gameFull&#x60;.
    */
  def boardGameStream(gameId: String): GameStreamEvent

  /**
    * Handle takeback offers
    * Create/accept/decline takebacks. - &#x60;yes&#x60;: Propose a takeback, or accept the opponent&#39;s takeback offer. - &#x60;no&#x60;: Decline a takeback offer from the opponent. 
    */
  def boardGameTakeback(gameId: String, accept: Boolean): Ok
}
