package api

import org.openapitools.OpenApiExceptions
import javax.inject.{Inject, Singleton}
import play.api.libs.json._
import play.api.mvc._
import model.ApiStreamEvent
import model.BigDecimal
import model.Error
import model.GameStreamEvent
import model.NotFound
import model.OasAnyTypeNotMapped
import model.Ok
import model.VariantKey

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
@Singleton
class BoardApiController @Inject()(cc: ControllerComponents, api: BoardApi) extends AbstractController(cc) {
  /**
    * POST /api/board/seek
    */
  def apiBoardSeek(): Action[AnyContent] = Action { request =>
    def executeApi(): Unit = {
      val rated = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("rated"))
        .flatMap(_.headOption)
        .map(value => value.toBoolean)
      val time = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("time"))
        .flatMap(_.headOption)
        .map(value => BigDecimal(value))
      val increment = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("increment"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
      val days = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("days"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
      val variant = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("variant"))
        .flatMap(_.headOption)
        .map(value => )
      val color = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("color"))
        .flatMap(_.headOption)
        
      val ratingRange = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("ratingRange"))
        .flatMap(_.headOption)
        
      api.apiBoardSeek(rated, time, increment, days, variant, color, ratingRange)
    }

    executeApi()
    Ok
  }

  /**
    * GET /api/stream/event
    */
  def apiStreamEvent(): Action[AnyContent] = Action { request =>
    def executeApi(): ApiStreamEvent = {
      api.apiStreamEvent()
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/board/game/:gameId/abort
    */
  def boardGameAbort(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.boardGameAbort(gameId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/board/game/:gameId/chat
    */
  def boardGameChatGet(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      api.boardGameChatGet(gameId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/board/game/:gameId/chat
    */
  def boardGameChatPost(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      val room = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("room"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("room", "form")
        }
      val text = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("text"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("text", "form")
        }
      api.boardGameChatPost(gameId, room, text)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/board/game/:gameId/claim-victory
    */
  def boardGameClaimVictory(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.boardGameClaimVictory(gameId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/board/game/:gameId/draw/:accept
    */
  def boardGameDraw(gameId: String, accept: Boolean): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.boardGameDraw(gameId, accept)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/board/game/:gameId/move/:move?offeringDraw=[value]
    * @param move The move to play, in UCI format
    */
  def boardGameMove(gameId: String, move: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      val offeringDraw = request.getQueryString("offeringDraw")
        .map(value => value.toBoolean)
      api.boardGameMove(gameId, move, offeringDraw)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/board/game/:gameId/resign
    */
  def boardGameResign(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.boardGameResign(gameId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/board/game/stream/:gameId
    */
  def boardGameStream(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): GameStreamEvent = {
      api.boardGameStream(gameId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/board/game/:gameId/takeback/:accept
    */
  def boardGameTakeback(gameId: String, accept: Boolean): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.boardGameTakeback(gameId, accept)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  private def splitCollectionParam(paramValues: String, collectionFormat: String): List[String] = {
    val splitBy =
      collectionFormat match {
        case "csv" => ",+"
        case "tsv" => "\t+"
        case "ssv" => " +"
        case "pipes" => "|+"
      }

    paramValues.split(splitBy).toList
  }
}
