package api

import play.api.libs.json._
import model.ApiStreamEvent
import model.Error
import model.GameStreamEvent
import model.NotFound
import model.Ok
import model.User

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait BotApi {
  /**
    * Get online bots
    * Stream the [online bot users](https://lichess.org/player/bots), as [ndjson](#section/Introduction/Streaming-with-ND-JSON). Throttled to 50 bot users per second.
    * @param nb How many bot users to fetch
    */
  def apiBotOnline(nb: Option[Int]): User

  /**
    * Stream incoming events
    *    Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameStart&#x60; Start of a game   - &#x60;gameFinish&#x60; Completion of a game   - &#x60;challenge&#x60; A player sends you a challenge   - &#x60;challengeCanceled&#x60; A player cancels their challenge to you   - &#x60;challengeDeclined&#x60; The opponent declines your challenge     When the stream opens, all current challenges and games are sent.
    */
  def apiStreamEvent(): ApiStreamEvent

  /**
    * Upgrade to Bot account
    * Upgrade a lichess player account into a Bot account. Only Bot accounts can use the Bot API.  The account **cannot have played any game** before becoming a Bot account. The upgrade is **irreversible**. The account will only be able to play as a Bot.  To upgrade an account to Bot, use the [official lichess-bot client](https://github.com/careless25/lichess-bot), or follow these steps: - Create an [API access token](https://lichess.org/account/oauth/token/create?scopes[]&#x3D;bot:play) with \&quot;Play bot moves\&quot; permission. - &#x60;curl -d &#39;&#39; https://lichess.org/api/bot/account/upgrade -H \&quot;Authorization: Bearer &lt;yourTokenHere&gt;\&quot;&#x60;  To know if an account has already been upgraded, use the [Get my profile API](#operation/accountMe): the &#x60;title&#x60; field should be set to &#x60;BOT&#x60;. 
    */
  def botAccountUpgrade(): Ok

  /**
    * Abort a game
    * Abort a game being played with the Bot API. 
    */
  def botGameAbort(gameId: String): Ok

  /**
    * Write in the chat
    * Post a message to the player or spectator chat, in a game being played with the Bot API. 
    */
  def botGameChat(gameId: String, room: String, text: String): Ok

  /**
    * Make a Bot move
    * Make a move in a game being played with the Bot API.  The move can also contain a draw offer/agreement. 
    * @param move The move to play, in UCI format
    * @param offeringDraw Whether to offer (or agree to) a draw
    */
  def botGameMove(gameId: String, move: String, offeringDraw: Option[Boolean]): Ok

  /**
    * Resign a game
    * Resign a game being played with the Bot API. 
    */
  def botGameResign(gameId: String): Ok

  /**
    * Stream Bot game state
    *  Stream the state of a game being played with the Bot API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameFull&#x60; Full game data. All values are immutable, except for the &#x60;state&#x60; field.   - &#x60;gameState&#x60; Current state of the game. Immutable values not included.   - &#x60;chatLine&#x60; Chat message sent by a user (or the bot itself) in the &#x60;room&#x60; \&quot;player\&quot; or \&quot;spectator\&quot;.    The first line is always of type &#x60;gameFull&#x60;.
    */
  def botGameStream(gameId: String): GameStreamEvent
}
