package api

import org.openapitools.OpenApiExceptions
import javax.inject.{Inject, Singleton}
import play.api.libs.json._
import play.api.mvc._
import model.ApiStreamEvent
import model.Error
import model.GameStreamEvent
import model.NotFound
import model.Ok
import model.User

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
@Singleton
class BotApiController @Inject()(cc: ControllerComponents, api: BotApi) extends AbstractController(cc) {
  /**
    * GET /api/bot/online?nb=[value]
    */
  def apiBotOnline(): Action[AnyContent] = Action { request =>
    def executeApi(): User = {
      val nb = request.getQueryString("nb")
        .map(value => value.toInt)
      api.apiBotOnline(nb)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/stream/event
    */
  def apiStreamEvent(): Action[AnyContent] = Action { request =>
    def executeApi(): ApiStreamEvent = {
      api.apiStreamEvent()
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/bot/account/upgrade
    */
  def botAccountUpgrade(): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.botAccountUpgrade()
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/bot/game/:gameId/abort
    */
  def botGameAbort(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.botGameAbort(gameId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/bot/game/:gameId/chat
    */
  def botGameChat(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      val room = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("room"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("room", "form")
        }
      val text = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("text"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("text", "form")
        }
      api.botGameChat(gameId, room, text)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/bot/game/:gameId/move/:move?offeringDraw=[value]
    * @param move The move to play, in UCI format
    */
  def botGameMove(gameId: String, move: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      val offeringDraw = request.getQueryString("offeringDraw")
        .map(value => value.toBoolean)
      api.botGameMove(gameId, move, offeringDraw)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/bot/game/:gameId/resign
    */
  def botGameResign(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.botGameResign(gameId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/bot/game/stream/:gameId
    */
  def botGameStream(gameId: String): Action[AnyContent] = Action { request =>
    def executeApi(): GameStreamEvent = {
      api.botGameStream(gameId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  private def splitCollectionParam(paramValues: String, collectionFormat: String): List[String] = {
    val splitBy =
      collectionFormat match {
        case "csv" => ",+"
        case "tsv" => "\t+"
        case "ssv" => " +"
        case "pipes" => "|+"
      }

    paramValues.split(splitBy).toList
  }
}
