package api

import play.api.libs.json._
import model.Error
import model.OasAnyTypeNotMapped
import model.Ok

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait BroadcastsApi {
  /**
    * Export all rounds as PGN
    * Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 
    * @param broadcastTournamentId The broadcast tournament ID (8 characters).
    */
  def broadcastAllRoundsPgn(broadcastTournamentId: String): OasAnyTypeNotMapped

  /**
    * Get official broadcasts
    * Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param nb Max number of broadcasts to fetch
    */
  def broadcastIndex(nb: Option[Int]): List[OasAnyTypeNotMapped]

  /**
    * Push PGN to your broadcast round
    * Update your broadcast with new PGN. Only for broadcast without a source URL. 
    * @param broadcastRoundId The broadcast round ID (8 characters).
    * @param body The PGN. It can contain up to 64 games, separated by a double new line.
    */
  def broadcastPush(broadcastRoundId: String, body: String): List[Ok]

  /**
    * Create a broadcast round
    * Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 
    * @param broadcastTournamentId The broadcast tournament ID (8 characters).
    * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60; 
    * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush). 
    * @param startsAt Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60; 
    */
  def broadcastRoundCreate(broadcastTournamentId: String, name: String, syncUrl: Option[String], startsAt: Option[Int]): OasAnyTypeNotMapped

  /**
    * Get your broadcast round
    * Get information about a broadcast round that you created. 
    * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used.
    * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used.
    * @param broadcastRoundId The broadcast Round ID (8 characters).
    */
  def broadcastRoundGet(broadcastTournamentSlug: String, broadcastRoundSlug: String, broadcastRoundId: String): List[OasAnyTypeNotMapped]

  /**
    * Export one round as PGN
    * Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 
    * @param broadcastRoundId The round ID (8 characters).
    */
  def broadcastRoundPgn(broadcastRoundId: String): OasAnyTypeNotMapped

  /**
    * Update your broadcast round
    * Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit &#x60;startDate&#x60;, then any pre-existing start date will be removed. 
    * @param broadcastRoundId The broadcast round ID (8 characters).
    * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60; 
    * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60; 
    * @param startsAt Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60; 
    */
  def broadcastRoundUpdate(broadcastRoundId: String, name: String, syncUrl: Option[String], startsAt: Option[Int]): Ok

  /**
    * Stream an ongoing broadcast tournament as PGN
    * This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 
    * @param broadcastRoundId The broadcast round ID (8 characters).
    */
  def broadcastStreamRoundPgn(broadcastRoundId: String): OasAnyTypeNotMapped

  /**
    * Create a broadcast tournament
    * Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 
    * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60; 
    * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60; 
    * @param markup Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters.
    * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
    */
  def broadcastTourCreate(name: String, description: String, markup: Option[String], official: Option[Boolean]): OasAnyTypeNotMapped

  /**
    * Get your broadcast tournament
    * Get information about a broadcast tournament that you created. 
    * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used.
    * @param broadcastTournamentId The broadcast tournament ID (8 characters).
    */
  def broadcastTourGet(slug: String, broadcastTournamentId: String): List[OasAnyTypeNotMapped]

  /**
    * Update your broadcast tournament
    * Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 
    * @param broadcastTournamentId The broadcast ID (8 characters).
    * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60; 
    * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60; 
    * @param markup Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters.
    * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
    */
  def broadcastTourUpdate(broadcastTournamentId: String, name: String, description: String, markup: Option[String], official: Option[Boolean]): Ok
}
