package api

import org.openapitools.OpenApiExceptions
import javax.inject.{Inject, Singleton}
import play.api.libs.json._
import play.api.mvc._
import model.Error
import model.OasAnyTypeNotMapped
import model.Ok

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
@Singleton
class BroadcastsApiController @Inject()(cc: ControllerComponents, api: BroadcastsApi) extends AbstractController(cc) {
  /**
    * GET /api/broadcast/:broadcastTournamentId.pgn
    * @param broadcastTournamentId The broadcast tournament ID (8 characters).
    */
  def broadcastAllRoundsPgn(broadcastTournamentId: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      api.broadcastAllRoundsPgn(broadcastTournamentId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/broadcast?nb=[value]
    */
  def broadcastIndex(): Action[AnyContent] = Action { request =>
    def executeApi(): List[OasAnyTypeNotMapped] = {
      val nb = request.getQueryString("nb")
        .map(value => value.toInt)
      api.broadcastIndex(nb)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /broadcast/round/:broadcastRoundId/push
    * @param broadcastRoundId The broadcast round ID (8 characters).
    */
  def broadcastPush(broadcastRoundId: String): Action[AnyContent] = Action { request =>
    def executeApi(): List[Ok] = {
      val body = request.body.asJson.map(_.as[String]).getOrElse {
        throw new OpenApiExceptions.MissingRequiredParameterException("body", "body")
      }
      api.broadcastPush(broadcastRoundId, body)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /broadcast/:broadcastTournamentId/new
    * @param broadcastTournamentId The broadcast tournament ID (8 characters).
    */
  def broadcastRoundCreate(broadcastTournamentId: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      val name = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("name"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("name", "form")
        }
      val syncUrl = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("syncUrl"))
        .flatMap(_.headOption)
        
      val startsAt = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("startsAt"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
      api.broadcastRoundCreate(broadcastTournamentId, name, syncUrl, startsAt)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /broadcast/:broadcastTournamentSlug/:broadcastRoundSlug/:broadcastRoundId
    * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used.
    * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used.
    * @param broadcastRoundId The broadcast Round ID (8 characters).
    */
  def broadcastRoundGet(broadcastTournamentSlug: String, broadcastRoundSlug: String, broadcastRoundId: String): Action[AnyContent] = Action { request =>
    def executeApi(): List[OasAnyTypeNotMapped] = {
      api.broadcastRoundGet(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/broadcast/round/:broadcastRoundId.pgn
    * @param broadcastRoundId The round ID (8 characters).
    */
  def broadcastRoundPgn(broadcastRoundId: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      api.broadcastRoundPgn(broadcastRoundId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /broadcast/round/:broadcastRoundId/edit
    * @param broadcastRoundId The broadcast round ID (8 characters).
    */
  def broadcastRoundUpdate(broadcastRoundId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      val name = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("name"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("name", "form")
        }
      val syncUrl = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("syncUrl"))
        .flatMap(_.headOption)
        
      val startsAt = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("startsAt"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
      api.broadcastRoundUpdate(broadcastRoundId, name, syncUrl, startsAt)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/stream/broadcast/round/:broadcastRoundId.pgn
    * @param broadcastRoundId The broadcast round ID (8 characters).
    */
  def broadcastStreamRoundPgn(broadcastRoundId: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      api.broadcastStreamRoundPgn(broadcastRoundId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /broadcast/new
    */
  def broadcastTourCreate(): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      val name = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("name"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("name", "form")
        }
      val description = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("description"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("description", "form")
        }
      val markup = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("markup"))
        .flatMap(_.headOption)
        
      val official = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("official"))
        .flatMap(_.headOption)
        .map(value => value.toBoolean)
      api.broadcastTourCreate(name, description, markup, official)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /broadcast/:slug/:broadcastTournamentId
    * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used.
    * @param broadcastTournamentId The broadcast tournament ID (8 characters).
    */
  def broadcastTourGet(slug: String, broadcastTournamentId: String): Action[AnyContent] = Action { request =>
    def executeApi(): List[OasAnyTypeNotMapped] = {
      api.broadcastTourGet(slug, broadcastTournamentId)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /broadcast/:broadcastTournamentId/edit
    * @param broadcastTournamentId The broadcast ID (8 characters).
    */
  def broadcastTourUpdate(broadcastTournamentId: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      val name = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("name"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("name", "form")
        }
      val description = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("description"))
        .flatMap(_.headOption)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("description", "form")
        }
      val markup = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("markup"))
        .flatMap(_.headOption)
        
      val official = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("official"))
        .flatMap(_.headOption)
        .map(value => value.toBoolean)
      api.broadcastTourUpdate(broadcastTournamentId, name, description, markup, official)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  private def splitCollectionParam(paramValues: String, collectionFormat: String): List[String] = {
    val splitBy =
      collectionFormat match {
        case "csv" => ",+"
        case "tsv" => "\t+"
        case "ssv" => " +"
        case "pipes" => "|+"
      }

    paramValues.split(splitBy).toList
  }
}
