package api

import play.api.libs.json._
import model.BigDecimal
import model.Error
import model.NotFound
import model.OasAnyTypeNotMapped
import model.Ok
import model.VariantKey

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait BulkPairingsApi {
  /**
    * Create a bulk pairing
    * Schedule many games at once, up to 24h in advance.  OAuth tokens are required for all paired players, with the &#x60;challenge:write&#x60; scope.  You can schedule up to 500 games every 10 minutes. [Contact us](mailto:contact@lichess.org) if you need higher limits.  The entire bulk is rejected if:   - a token is missing   - a token is present more than once   - a token lacks the &#x60;challenge:write&#x60; scope   - a player account is closed   - a player is paired more than once   - a bulk is already scheduled to start at the same time with the same player   - you have 10 scheduled bulks   - you have 1000 scheduled games  Partial bulks are never created. Either it all fails, or it all succeeds. When it fails, it does so with an error message explaining the issue. Failed bulks are not counted in the rate limiting, they are free. Fix the issues, manually or programmatically, then retry to schedule the bulk.  A successful bulk creation returns a JSON bulk document. Its ID can be used for further operations. 
    * @param players OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60; 
    * @param clockPeriodlimit Clock initial time in seconds. Example: &#x60;600&#x60; 
    * @param clockPeriodincrement Clock increment in seconds. Example: &#x60;5&#x60; 
    * @param pairAt Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60; 
    * @param startClocksAt Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60; 
    * @param rated Game is rated and impacts players ratings
    * @param message Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder. 
    */
  def bulkPairingCreate(players: Option[String], clockPeriodlimit: Option[BigDecimal], clockPeriodincrement: Option[Int], pairAt: Option[Int], startClocksAt: Option[Int], rated: Option[Boolean], variant: Option[VariantKey], message: Option[String]): OasAnyTypeNotMapped

  /**
    * Cancel a bulk pairing
    * Cancel and delete a bulk pairing that is scheduled in the future.  If the games have already been created, then this does nothing.  Canceling a bulk pairing does not refund the rate limit cost of that bulk pairing. 
    */
  def bulkPairingDelete(id: String): Ok

  /**
    * View upcoming bulk pairings
    * Get a list of upcoming bulk pairings you created.  Only bulk pairings that are scheduled in the future, or that have a clock start scheduled in the future, are listed.  Bulk pairings are deleted from the server after the pairings are done and the clocks have started. 
    */
  def bulkPairingGet(): List[OasAnyTypeNotMapped]

  /**
    * Manually start clocks
    * Immediately start all clocks of the games of a bulk pairing.  This overrides the &#x60;startClocksAt&#x60; value of an existing bulk pairing.  If the games have not yet been created (&#x60;bulk.pairAt&#x60; is in the future), then this does nothing.  If the clocks have already started (&#x60;bulk.startClocksAt&#x60; is in the past), then this does nothing. 
    */
  def bulkPairingStartClocks(id: String): Ok
}
