package api

import play.api.libs.json._
import model.BigDecimal
import model.ChallengeJson
import model.Error
import model.GameJson
import model.InlineResponse2003
import model.NotFound
import model.OasAnyTypeNotMapped
import model.Ok
import model.VariantKey

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait ChallengesApi {
  /**
    * Admin challenge tokens
    * **For administrators only. You are not allowed to use this endpoint.**  Create and obtain &#x60;challenge:write&#x60; tokens for multiple users.  If a similar token already exists for a user, it is reused. This endpoint is idempotent. 
    * @param users Usernames separated with commas
    * @param description User visible description of the token
    */
  def adminChallengeTokens(users: String, description: String): Unit

  /**
    * Accept a challenge
    * Accept an incoming challenge.  You should receive a &#x60;gameStart&#x60; event on the [incoming events stream](#operation/apiStreamEvent). 
    */
  def challengeAccept(challengeId: String): Ok

  /**
    * Challenge the AI
    * Start a game with Lichess AI.  You will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. 
    * @param level AI strength
    * @param clockPeriodlimit Clock initial time in seconds. If empty, a correspondence game is created.
    * @param clockPeriodincrement Clock increment in seconds. If empty, a correspondence game is created.
    * @param days Days per move, for correspondence games. Clock settings must be omitted.
    * @param color Which color you get to play
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
    */
  def challengeAi(level: Option[BigDecimal], clockPeriodlimit: Option[BigDecimal], clockPeriodincrement: Option[Int], days: Option[Int], color: Option[String], variant: Option[VariantKey], fen: Option[String]): GameJson

  /**
    * Cancel a challenge
    * Cancel a challenge you sent, or aborts the game if the challenge was accepted, but the game was not yet played. Note that the ID of a game is the same as the ID of the challenge that created it. 
    * @param opponentToken Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved.
    */
  def challengeCancel(challengeId: String, opponentToken: Option[String]): Ok

  /**
    * Create a challenge
    * Challenge someone to play. The targeted player can choose to accept or decline.  If the challenge is accepted, you will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. The game ID will be the same as the challenge ID.  If you also have an OAuth token with &#x60;challenge:write&#x60; scope for the receiving user, you can make them accept the challenge immediately by setting the &#x60;acceptByToken&#x60; field.  Challenges for realtime games (not correspondence) expire after 20s if not accepted. To prevent that, use the &#x60;keepAliveStream&#x60; flag described below. 
    * @param rated Game is rated and impacts players ratings
    * @param clockPeriodlimit Clock initial time in seconds. If empty, a correspondence game is created.
    * @param clockPeriodincrement Clock increment in seconds. If empty, a correspondence game is created.
    * @param days Days per move, for correspondence games. Clock settings must be omitted.
    * @param color Which color you get to play
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1.
    * @param keepAliveStream If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted. 
    * @param acceptByToken Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate). 
    * @param message **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder. 
    */
  def challengeCreate(username: String, rated: Option[Boolean], clockPeriodlimit: Option[BigDecimal], clockPeriodincrement: Option[Int], days: Option[Int], color: Option[String], variant: Option[VariantKey], fen: Option[String], keepAliveStream: Option[Boolean], acceptByToken: Option[String], message: Option[String]): ChallengeJson

  /**
    * Decline a challenge
    * Decline an incoming challenge. 
    * @param reason Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14).
    */
  def challengeDecline(challengeId: String, reason: Option[String]): Ok

  /**
    * List your challenges
    * Get a list of challenges created by or targeted at you. 
    */
  def challengeList(): InlineResponse2003

  /**
    * Open-ended challenge
    * Create a challenge that any 2 players can join.  Share the URL of the challenge. the first 2 players to click it will be paired for a game.  The response body also contains &#x60;whiteUrl&#x60; and &#x60;blackUrl&#x60;. You can control which color each player gets by giving them these URLs, instead of the main challenge URL.  Open challenges expire after 24h.  To directly pair 2 known players, use [this endpoint](#operation/challengeCreate) instead, with the &#x60;acceptByToken&#x60; parameter. 
    * @param rated Game is rated and impacts players ratings
    * @param clockPeriodlimit Clock initial time in seconds. If empty, a correspondence game is created.
    * @param clockPeriodincrement Clock increment in seconds. If empty, a correspondence game is created.
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
    * @param name Optional name for the challenge, that players will see on the challenge page.
    */
  def challengeOpen(rated: Option[Boolean], clockPeriodlimit: Option[BigDecimal], clockPeriodincrement: Option[Int], variant: Option[VariantKey], fen: Option[String], name: Option[String]): OasAnyTypeNotMapped

  /**
    * Start clocks of a game
    * Start the clocks of a game immediately, even if a player has not yet made a move.  Requires the OAuth tokens of both players with &#x60;challenge:write&#x60; scope.  If the clocks have already started, the call will have no effect. 
    * @param token1 OAuth token of a player
    * @param token2 OAuth token of the other player
    */
  def challengeStartClocks(gameId: String, token1: Option[String], token2: Option[String]): Ok

  /**
    * Add time to the opponent clock
    * Add seconds to the opponent&#39;s clock. Can be used to create games with time odds. 
    * @param seconds How many seconds to give
    */
  def roundAddTime(gameId: String, seconds: String): Ok
}
