package api

import play.api.libs.json._
import model.OasAnyTypeNotMapped
import model.PerfType

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait GamesApi {
  /**
    * Get my ongoing games
    * Get the ongoing games of the current user. Real-time and correspondence games are included. The most urgent games are listed first. 
    * @param nb Max number of games to fetch
    */
  def apiAccountPlaying(nb: Option[Int]): OasAnyTypeNotMapped

  /**
    * Export games of a user
    * Download all games of any user in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. &lt;https://lichess.org/@/german11&gt; for instance has more than 320,000 games.  The game stream is throttled, depending on who is making the request:   - Anonymous request: 20 games per second   - [OAuth2 authenticated](#section/Authentication) request: 30 games per second   - Authenticated, downloading your own games: 60 games per second 
    * @param username The user name.
    * @param since Download games played since this timestamp.
    * @param until Download games played until this timestamp.
    * @param max How many games to download. Leave empty to download all games.
    * @param vs [Filter] Only games played against this opponent
    * @param rated [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games
    * @param perfType [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical
    * @param color [Filter] Only games played as this color.
    * @param analysed [Filter] Only games with or without a computer analysis available
    * @param moves Include the PGN moves.
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header.
    * @param tags Include the PGN tags.
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
    * @param ongoing Include ongoing games. The last 3 moves will be omitted.
    * @param finished Include finished games. Set to &#x60;false&#x60; to only get ongoing games.
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
    * @param sort Sort order of the games.
    */
  def apiGamesUser(username: String, since: Option[Int], until: Option[Int], max: Option[Int], vs: Option[String], rated: Option[Boolean], perfType: Option[PerfType], color: Option[String], analysed: Option[Boolean], moves: Option[Boolean], pgnInJson: Option[Boolean], tags: Option[Boolean], clocks: Option[Boolean], evals: Option[Boolean], opening: Option[Boolean], ongoing: Option[Boolean], finished: Option[Boolean], players: Option[String], sort: Option[String]): OasAnyTypeNotMapped

  /**
    * Export ongoing game of a user
    * Download the ongoing game, or the last game played, of a user. Available in either PGN or JSON format. If the game is ongoing, the 3 last moves are omitted. 
    * @param moves Include the PGN moves.
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
    * @param tags Include the PGN tags.
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
    * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60; 
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
    */
  def apiUserCurrentGame(username: String, moves: Option[Boolean], pgnInJson: Option[Boolean], tags: Option[Boolean], clocks: Option[Boolean], evals: Option[Boolean], opening: Option[Boolean], literate: Option[Boolean], players: Option[String]): OasAnyTypeNotMapped

  /**
    * Import one game
    * Import a game from PGN. See &lt;https://lichess.org/paste&gt;.  Rate limiting: 200 games per hour for OAuth requests, 100 games per hour for anonymous requests.  To broadcast ongoing games, consider [pushing to a broadcast instead](#operation/broadcastPush). 
    * @param pgn The PGN. It can contain only one game. Most standard tags are supported.
    */
  def gameImport(pgn: Option[String]): OasAnyTypeNotMapped

  /**
    * Export one game
    * Download one game in either PGN or JSON format.  Ongoing games have their last 3 moves omitted, after move 5. 
    * @param gameId The game ID (8 characters).
    * @param moves Include the PGN moves.
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
    * @param tags Include the PGN tags.
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
    * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60; 
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
    */
  def gamePgn(gameId: String, moves: Option[Boolean], pgnInJson: Option[Boolean], tags: Option[Boolean], clocks: Option[Boolean], evals: Option[Boolean], opening: Option[Boolean], literate: Option[Boolean], players: Option[String]): OasAnyTypeNotMapped

  /**
    * Stream games of users
    * Stream the games played between a list of users, in real time. Only games where **both players** are part of the list are included.  By default, games are only sent to the stream when they start. To also get all ongoing games at the beginning of the stream, use the &#x60;withCurrentGames&#x60; flag.  Maximum number of users: 300.  Games are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body. 
    * @param body Up to 300 user IDs separated by commas.
    * @param withCurrentGames Include the already started games at the beginning of the stream.
    */
  def gamesByUsers(body: String, withCurrentGames: Option[Boolean]): OasAnyTypeNotMapped

  /**
    * Export games by IDs
    * Download games by IDs in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header.  Games are sorted by reverse chronological order (most recent first)  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body.  300 IDs can be submitted.  Ongoing games have their last 3 moves omitted, after move 5. 
    * @param body Game IDs separated by commas. Up to 300.
    * @param moves Include the PGN moves.
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
    * @param tags Include the PGN tags.
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
    */
  def gamesExportIds(body: String, moves: Option[Boolean], pgnInJson: Option[Boolean], tags: Option[Boolean], clocks: Option[Boolean], evals: Option[Boolean], opening: Option[Boolean], players: Option[String]): OasAnyTypeNotMapped

  /**
    * Stream moves of a game
    * Stream positions and moves of any ongoing game, in [ndjson](#section/Introduction/Streaming-with-ND-JSON).  A description of the game is sent as a first message. Then a message is sent each time a move is played. Finally a description of the game is sent when it finishes, and the stream is closed.  After move 5, the stream intentionally remains 3 moves behind the game status, as to prevent cheat bots from using this API.  No more than 8 game streams can be opened at the same time from the same IP address. 
    */
  def streamGame(id: String): OasAnyTypeNotMapped
}
