package api

import play.api.libs.json._
import model.BigDecimal
import model.OasAnyTypeNotMapped
import model.Speed
import model.VariantKey

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait OpeningExplorerApi {
  /**
    * Lichess games
    * **Endpoint: &lt;https://explorer.lichess.ovh/lichess&gt;**  Games sampled from all Lichess players.  Example: &#x60;curl https://explorer.lichess.ovh/lichess?variant&#x3D;standard&amp;speeds&#x3D;blitz,rapid,classical&amp;ratings&#x3D;2200,2500&amp;fen&#x3D;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201&#x60; 
    * @param variant Variant
    * @param fen FEN of the root position
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
    * @param speeds Comma separated list of game speeds to look for
    * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group
    * @param since Include only games from this month or later
    * @param until Include only games from this month or earlier
    * @param moves Number of most common moves to display
    * @param topGames Number of top games to display
    * @param recentGames Number of recent games to display
    */
  def openingExplorerLichess(variant: Option[VariantKey], fen: Option[String], play: Option[String], speeds: Option[List[Speed]], ratings: Option[List[BigDecimal]], since: Option[String], until: Option[String], moves: Option[BigDecimal], topGames: Option[BigDecimal], recentGames: Option[BigDecimal]): OasAnyTypeNotMapped

  /**
    * Masters database
    * **Endpoint: &lt;https://explorer.lichess.ovh/masters&gt;**  Example: &#x60;curl https://explorer.lichess.ovh/masters?play&#x3D;d2d4,d7d5,c2c4,c7c6,c4d5&#x60; 
    * @param fen FEN of the root position
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
    * @param since Include only games from this year or later
    * @param until Include only games from thi year or earlier
    * @param moves Number of most common moves to display
    * @param topGames Number of top games to display
    */
  def openingExplorerMaster(fen: Option[String], play: Option[String], since: Option[BigDecimal], until: Option[BigDecimal], moves: Option[BigDecimal], topGames: Option[BigDecimal]): OasAnyTypeNotMapped

  /**
    * OTB master game
    * **Endpoint: &#x60;https://explorer.lichess.ovh/masters/pgn/{gameId}&#x60;**  Example: &#x60;curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey&#x60; 
    */
  def openingExplorerMasterGame(gameId: String): OasAnyTypeNotMapped

  /**
    * Player games
    * **Endpoint: &lt;https://explorer.lichess.ovh/player&gt;**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: &#x60;curl https://explorer.lichess.ovh/player?player&#x3D;revoof&amp;color&#x3D;white&amp;play&#x3D;d2d4,d7d5&amp;recentGames&#x3D;1&#x60; 
    * @param variant Variant
    * @param fen FEN of the root position
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position. 
    * @param speeds Comma separated list of game speeds to look for
    * @param modes Comma separated list of modes
    * @param since Include only games from this month or later
    * @param until Include only games from this month or earlier
    * @param moves Number of most common moves to display
    * @param recentGames Number of recent games to display
    */
  def openingExplorerPlayer(variant: Option[VariantKey], fen: Option[String], play: Option[String], speeds: Option[List[Speed]], modes: Option[List[String]], since: Option[String], until: Option[String], moves: Option[BigDecimal], recentGames: Option[BigDecimal]): OasAnyTypeNotMapped
}
