package api

import play.api.libs.json._
import model.BigDecimal
import model.Error
import model.OasAnyTypeNotMapped
import model.Ok
import model.SwissUnauthorisedEdit
import model.VariantKey

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait SwissTournamentsApi {
  /**
    * Join a Swiss tournament
    * Join a Swiss tournament, possibly with a password. 
    * @param id The tournament ID.
    * @param password The tournament password, if one is required
    */
  def apiSwissJoin(id: String, password: Option[String]): Ok

  /**
    * Create a new Swiss tournament
    * Create a Swiss tournament for your team.  This endpoint mirrors the Swiss tournament form from your team pagee.  You can create up to 12 tournaments per day. 
    * @param teamId ID of the team
    * @param clockPeriodlimit Clock initial time in seconds
    * @param clockPeriodincrement Clock increment in seconds
    * @param nbRounds Maximum number of rounds to play
    * @param name The tournament name. Leave empty to get a random Grandmaster name
    * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
    * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
    * @param description Anything you want to tell players about the tournament
    * @param rated Games are rated and impact players ratings
    * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players 
    */
  def apiSwissNew(teamId: String, clockPeriodlimit: BigDecimal, clockPeriodincrement: Int, nbRounds: Int, name: Option[String], startsAt: Option[Int], roundInterval: Option[Int], variant: Option[VariantKey], description: Option[String], rated: Option[Boolean], chatFor: Option[BigDecimal]): OasAnyTypeNotMapped

  /**
    * Terminate a Swiss tournament
    * Terminate a Swiss tournament 
    * @param id The Swiss tournament ID.
    */
  def apiSwissTerminate(id: String): Ok

  /**
    * Update a Swiss tournament.
    * Update a Swiss tournament.  Be mindful not to make important changes to ongoing tournaments. 
    * @param id The tournament ID.
    * @param clockPeriodlimit Clock initial time in seconds
    * @param clockPeriodincrement Clock increment in seconds
    * @param nbRounds Maximum number of rounds to play
    * @param name The tournament name. Leave empty to get a random Grandmaster name
    * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
    * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
    * @param description Anything you want to tell players about the tournament
    * @param rated Games are rated and impact players ratings
    * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players 
    */
  def apiSwissUpdate(id: String, clockPeriodlimit: BigDecimal, clockPeriodincrement: Int, nbRounds: Int, name: Option[String], startsAt: Option[Int], roundInterval: Option[Int], variant: Option[VariantKey], description: Option[String], rated: Option[Boolean], chatFor: Option[BigDecimal]): OasAnyTypeNotMapped

  /**
    * Get team swiss tournaments
    * Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param max How many tournaments to download.
    */
  def apiTeamSwiss(teamId: String, max: Option[Int]): List[OasAnyTypeNotMapped]

  /**
    * Export games of a Swiss tournament
    * Download games of a swiss tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (last round first) 
    * @param id The tournament ID.
    * @param moves Include the PGN moves.
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
    * @param tags Include the PGN tags.
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
    */
  def gamesBySwiss(id: String, moves: Option[Boolean], pgnInJson: Option[Boolean], tags: Option[Boolean], clocks: Option[Boolean], evals: Option[Boolean], opening: Option[Boolean]): OasAnyTypeNotMapped

  /**
    * Get results of a swiss tournament
    * Players of a swiss tournament, with their score and performance, sorted by rank (best first).  Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
    * @param id The tournament ID.
    * @param nb Max number of players to fetch
    */
  def resultsBySwiss(id: String, nb: Option[Int]): OasAnyTypeNotMapped

  /**
    * Export TRF of a Swiss tournament
    * Download a tournament in the Tournament Report File format, the FIDE standard.  Documentation: &lt;https://www.fide.com/FIDE/handbook/C04Annex2_TRF16.pdf&gt;  Example: &lt;https://lichess.org/swiss/j8rtJ5GL.trf&gt; 
    * @param id The tournament ID.
    */
  def swissTrf(id: String): String
}
