package api

import org.openapitools.OpenApiExceptions
import javax.inject.{Inject, Singleton}
import play.api.libs.json._
import play.api.mvc._
import model.BigDecimal
import model.Error
import model.OasAnyTypeNotMapped
import model.Ok
import model.SwissUnauthorisedEdit
import model.VariantKey

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
@Singleton
class SwissTournamentsApiController @Inject()(cc: ControllerComponents, api: SwissTournamentsApi) extends AbstractController(cc) {
  /**
    * POST /api/swiss/:id/join
    * @param id The tournament ID.
    */
  def apiSwissJoin(id: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      val password = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("password"))
        .flatMap(_.headOption)
        
      api.apiSwissJoin(id, password)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/swiss/new/:teamId
    * @param teamId ID of the team
    */
  def apiSwissNew(teamId: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      val name = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("name"))
        .flatMap(_.headOption)
        
      val clockPeriodlimit = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("clock.limit"))
        .flatMap(_.headOption)
        .map(value => BigDecimal(value))
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("clock.limit", "form")
        }
      val clockPeriodincrement = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("clock.increment"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("clock.increment", "form")
        }
      val nbRounds = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("nbRounds"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("nbRounds", "form")
        }
      val startsAt = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("startsAt"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
      val roundInterval = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("roundInterval"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
      val variant = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("variant"))
        .flatMap(_.headOption)
        .map(value => )
      val description = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("description"))
        .flatMap(_.headOption)
        
      val rated = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("rated"))
        .flatMap(_.headOption)
        .map(value => value.toBoolean)
      val chatFor = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("chatFor"))
        .flatMap(_.headOption)
        .map(value => BigDecimal(value))
      api.apiSwissNew(teamId, clockPeriodlimit, clockPeriodincrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/swiss/:id/terminate
    * @param id The Swiss tournament ID.
    */
  def apiSwissTerminate(id: String): Action[AnyContent] = Action { request =>
    def executeApi(): Ok = {
      api.apiSwissTerminate(id)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * POST /api/swiss/:id/edit
    * @param id The tournament ID.
    */
  def apiSwissUpdate(id: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      val name = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("name"))
        .flatMap(_.headOption)
        
      val clockPeriodlimit = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("clock.limit"))
        .flatMap(_.headOption)
        .map(value => BigDecimal(value))
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("clock.limit", "form")
        }
      val clockPeriodincrement = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("clock.increment"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("clock.increment", "form")
        }
      val nbRounds = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("nbRounds"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
        .getOrElse {
          throw new OpenApiExceptions.MissingRequiredParameterException("nbRounds", "form")
        }
      val startsAt = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("startsAt"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
      val roundInterval = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("roundInterval"))
        .flatMap(_.headOption)
        .map(value => value.toInt)
      val variant = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("variant"))
        .flatMap(_.headOption)
        .map(value => )
      val description = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("description"))
        .flatMap(_.headOption)
        
      val rated = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("rated"))
        .flatMap(_.headOption)
        .map(value => value.toBoolean)
      val chatFor = (request.body.asMultipartFormData.map(_.asFormUrlEncoded) orElse request.body.asFormUrlEncoded)
        .flatMap(_.get("chatFor"))
        .flatMap(_.headOption)
        .map(value => BigDecimal(value))
      api.apiSwissUpdate(id, clockPeriodlimit, clockPeriodincrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/team/:teamId/swiss?max=[value]
    */
  def apiTeamSwiss(teamId: String): Action[AnyContent] = Action { request =>
    def executeApi(): List[OasAnyTypeNotMapped] = {
      val max = request.getQueryString("max")
        .map(value => value.toInt)
      api.apiTeamSwiss(teamId, max)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/swiss/:id/games?moves=[value]&pgnInJson=[value]&tags=[value]&clocks=[value]&evals=[value]&opening=[value]
    * @param id The tournament ID.
    */
  def gamesBySwiss(id: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      val moves = request.getQueryString("moves")
        .map(value => value.toBoolean)
      val pgnInJson = request.getQueryString("pgnInJson")
        .map(value => value.toBoolean)
      val tags = request.getQueryString("tags")
        .map(value => value.toBoolean)
      val clocks = request.getQueryString("clocks")
        .map(value => value.toBoolean)
      val evals = request.getQueryString("evals")
        .map(value => value.toBoolean)
      val opening = request.getQueryString("opening")
        .map(value => value.toBoolean)
      api.gamesBySwiss(id, moves, pgnInJson, tags, clocks, evals, opening)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /api/swiss/:id/results?nb=[value]
    * @param id The tournament ID.
    */
  def resultsBySwiss(id: String): Action[AnyContent] = Action { request =>
    def executeApi(): OasAnyTypeNotMapped = {
      val nb = request.getQueryString("nb")
        .map(value => value.toInt)
      api.resultsBySwiss(id, nb)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  /**
    * GET /swiss/:id.trf
    * @param id The tournament ID.
    */
  def swissTrf(id: String): Action[AnyContent] = Action { request =>
    def executeApi(): String = {
      api.swissTrf(id)
    }

    val result = executeApi()
    val json = Json.toJson(result)
    Ok(json)
  }

  private def splitCollectionParam(paramValues: String, collectionFormat: String): List[String] = {
    val splitBy =
      collectionFormat match {
        case "csv" => ",+"
        case "tsv" => "\t+"
        case "ssv" => " +"
        case "pipes" => "|+"
      }

    paramValues.split(splitBy).toList
  }
}
