package api

import play.api.libs.json._
import model.BigDecimal
import model.Error
import model.InlineResponse2001
import model.OasAnyTypeNotMapped
import model.Ok
import model.Team
import model.UserExtended

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait TeamsApi {
  /**
    * Get team Arena tournaments
    * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param teamId ID of the team
    * @param max How many tournaments to download.
    */
  def apiTeamArena(teamId: String, max: Option[Int]): List[OasAnyTypeNotMapped]

  /**
    * Get team swiss tournaments
    * Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param max How many tournaments to download.
    */
  def apiTeamSwiss(teamId: String, max: Option[Int]): List[OasAnyTypeNotMapped]

  /**
    * Get popular teams
    * Paginator of the most popular teams. 
    */
  def teamAll(page: Option[BigDecimal]): InlineResponse2001

  /**
    * Join a team
    * Join a team. If the team requires a password but the &#x60;password&#x60; field is incorrect, then the call fails with &#x60;403 Forbidden&#x60;. Similarly, if the team join policy requires a confirmation but the &#x60;message&#x60; parameter is not given, then the call fails with &#x60;403 Forbidden&#x60;. 
    * @param message Optional request message, if the team requires one.
    * @param password Optional password, if the team requires one.
    */
  def teamIdJoin(teamId: String, message: Option[String], password: Option[String]): Ok

  /**
    * Kick a user from your team
    * Kick a member out of one of your teams. - &lt;https://lichess.org/team&gt; 
    */
  def teamIdKickUserId(teamId: String, userId: String): Ok

  /**
    * Message all members
    * Send a private message to all members of a team. You must own the team. 
    * @param message The message to send to all your team members.
    */
  def teamIdPmAll(teamId: String, message: Option[String]): Ok

  /**
    * Leave a team
    * Leave a team. - &lt;https://lichess.org/team&gt; 
    */
  def teamIdQuit(teamId: String): Ok

  /**
    * Get members of a team
    * Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    */
  def teamIdUsers(teamId: String): UserExtended

  /**
    * Teams of a player
    * All the teams a player is a member of. 
    */
  def teamOfUsername(username: String): List[Team]

  /**
    * Search teams
    * Paginator of team search results for a keyword. 
    */
  def teamSearch(text: Option[String], page: Option[BigDecimal]): List[Team]

  /**
    * Get a single team
    * Infos about a team
    */
  def teamShow(teamId: String): Team
}
