package api

import play.api.libs.json._
import model.InlineResponse200
import model.InlineResponse2002
import model.OasAnyTypeNotMapped
import model.PerfType
import model.User
import model.UserExtended

@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
trait UsersApi {
  /**
    * Get crosstable
    * Get total number of games, and current score, of any two users.  If the &#x60;matchup&#x60; flag is provided, and the users are currently playing, also gets the current match game number and scores. 
    * @param matchup Whether to get the current match data, if any
    */
  def apiCrosstable(user1: String, user2: String, matchup: Option[Boolean]): OasAnyTypeNotMapped

  /**
    * Get user public data
    * Read public data of a user. 
    */
  def apiUser(username: String): UserExtended

  /**
    * Get user activity
    * Read data to generate the activity feed of a user. 
    */
  def apiUserActivity(username: String): Unit

  /**
    * Get performance statistics of a user
    * Read performance statistics of a user, for a single performance. Similar to the [performance pages on the website](https://lichess.org/@/thibault/perf/bullet). 
    */
  def apiUserPerf(username: String, perf: PerfType): OasAnyTypeNotMapped

  /**
    * Get rating history of a user
    * Read rating history of a user, for all perf types. There is at most one entry per day. Format of an entry is &#x60;[year, month, day, rating]&#x60;. &#x60;month&#x60; starts at zero (January). 
    */
  def apiUserRatingHistory(username: String): OasAnyTypeNotMapped

  /**
    * Get users by ID
    * Get up to 300 users by their IDs. Users are returned in the same order as the IDs.  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body. 
    * @param body User IDs separated by commas.
    */
  def apiUsers(body: String): List[User]

  /**
    * Get real-time users status
    * Read the &#x60;online&#x60;, &#x60;playing&#x60; and &#x60;streaming&#x60; flags of several users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds).  Use it to track players and know when they&#39;re connected on lichess and playing games. 
    * @param ids User IDs separated by commas. Up to 100 IDs.
    */
  def apiUsersStatus(ids: String): List[InlineResponse200]

  /**
    * Get all top 10
    * Get the top 10 players for each speed and variant.  See &lt;https://lichess.org/player&gt;. 
    */
  def player(): OasAnyTypeNotMapped

  /**
    * Get one leaderboard
    * Get the leaderboard for a single speed or variant (a.k.a. &#x60;perfType&#x60;). There is no leaderboard for correspondence or puzzles.  See &lt;https://lichess.org/player/top/200/bullet&gt;. 
    * @param nb How many users to fetch
    * @param perfType The speed or variant
    */
  def playerTopNbPerfType(nb: Int, perfType: String): OasAnyTypeNotMapped

  /**
    * Get live streamers
    * Get basic info about currently streaming users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds). 
    */
  def streamerLive(): List[InlineResponse2002]

  /**
    * Get members of a team
    * Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    */
  def teamIdUsers(teamId: String): UserExtended
}
