package model

import play.api.libs.json._

/**
  * Represents the Swagger definition for TablebaseJson.
  * @param category `cursed-win` and `blessed-loss` means the 50-move rule prevents the decisive result.  `maybe-win` and `maybe-loss` means exact result is unknown due to [DTZ rounding](https://syzygy-tables.info/metrics#dtz), i.e., the win or loss could also be prevented by the 50-move rule if the user has deviated from the tablebase recommendation since the last pawn move or capture. 
  * @param dtz [DTZ50'' with rounding](https://syzygy-tables.info/metrics#dtz) or null if unknown 
  * @param dtm Distance to mate (only for positions with not more than 5 pieces)
  * @param variantWin Only in chess variants
  * @param variantLoss Only in chess variants
  * @param moves Information about legal moves, best first
  * @param additionalProperties Any additional properties this model may have.
  */
@javax.annotation.Generated(value = Array("org.openapitools.codegen.languages.ScalaPlayFrameworkServerCodegen"), date = "2021-12-01T01:36:35.216324+01:00[Europe/Vienna]")
case class TablebaseJson(
  category: Option[TablebaseJson.Category.Value],
  dtz: Option[Int],
  dtm: Option[Int],
  checkmate: Option[Boolean],
  stalemate: Option[Boolean],
  variantWin: Option[Boolean],
  variantLoss: Option[Boolean],
  insufficientMaterial: Option[Boolean],
  moves: Option[List[Move]]
  additionalProperties: 
)

object TablebaseJson {
  implicit lazy val tablebaseJsonJsonFormat: Format[TablebaseJson] = {
    val realJsonFormat = Json.format[TablebaseJson]
    val declaredPropNames = Set("category", "dtz", "dtm", "checkmate", "stalemate", "variantWin", "variantLoss", "insufficientMaterial", "moves")
    
    Format(
      Reads {
        case JsObject(xs) =>
          val declaredProps = xs.filterKeys(declaredPropNames)
          val additionalProps = JsObject(xs -- declaredPropNames)
          val restructuredProps = declaredProps + ("additionalProperties" -> additionalProps)
          val newObj = JsObject(restructuredProps)
          realJsonFormat.reads(newObj)
        case _ =>
          JsError("error.expected.jsobject")
      },
      Writes { tablebaseJson =>
        val jsObj = realJsonFormat.writes(tablebaseJson)
        val additionalProps = jsObj.value("additionalProperties").as[JsObject]
        val declaredProps = jsObj - "additionalProperties"
        val newObj = declaredProps ++ additionalProps
        newObj
      }
    )
  }

  // noinspection TypeAnnotation
  object Category extends Enumeration {
    val Win = Value("win")
    val Unknown = Value("unknown")
    val MaybeWin = Value("maybe-win")
    val CursedWin = Value("cursed-win")
    val Draw = Value("draw")
    val BlessedLoss = Value("blessed-loss")
    val MaybeLoss = Value("maybe-loss")
    val Loss = Value("loss")

    type Category = Value
    implicit lazy val CategoryJsonFormat: Format[Value] = Format(Reads.enumNameReads(this), Writes.enumNameWrites[this.type])
  }
}

